import requests as r

#Global Variables
authurl = r'https://id.peloton.com/connect/authorize'
tokenurl = r'https://id.peloton.com/connect/token'
callbackurl = r'https://portal.peloton.com'
Scope = r'openid profile offline_access'
rooturl = r'https://api.peloton.com/v1.1'
TokenName = r'Prod PCE'
target_app = r'wellview'
lookuptablename = r'libjobjobtyp'

#access token grants below

token_headers = {"Content-type": 'application/x-www-form-urlencoded'}

def getAccessToken(refreshToken,clientID,clientSecret):
    token_params =  {
            'grant_type': 'refresh_token',
           'refresh_token':refreshToken,
           'client_id':clientID,
           'client_secret':clientSecret
                     }
    auth = r.post(tokenurl,data=token_params,headers=token_headers)
    if auth.status_code == 200:
        return auth
    else:
        print('Bad API Request: Status %s ' %(auth.status_code), ',Status Text: %s' %(auth.text))
        return auth


#API Calls
def getUser(access_token,subscription_key):
    call_headers = {"Content-Type":'application/json',
                    "Authorization":"Bearer %s" %(access_token),
                    "Ocp-Apim-Subscription-Key":subscription_key}
    user = r.get(url=rooturl+'/user',headers=call_headers)
    if user.status_code == 200:
        return user
    else:
        print('Bad API Request: Status %s ' %(user.status_code), ',Status Text: %s' %(user.text))
        return user

def getApplicationHeaders(user):
    apps = user.json()['organizations'][0]['applications']
    for i in range(0,len(apps)):
        if apps[i]['appid'] == 'SiteView':
            siteView = apps[i]['headervalue']
        elif apps[i]['appid'] =='WellView':
            wellView = apps[i]['headervalue']
    return siteView,wellView
        



import requests as r

def getsvTableAll(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    url = F"{rootUrl}/{activeOU}/siteview/data/{table}?pagesize={pagesize}&cursor={cursor}"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getsvTableChanges(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor,date):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    url = F"{rootUrl}/{activeOU}/siteview/data/changedrecords/{table}?pagesize={pagesize}&cursor={cursor}&startdateutc={date}"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getsvTableSingleFilter(access_token,subscription_key,rootUrl,activeOU,siteview,table,pagesize,cursor,filterColumn,filterValue):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    url = F"{rootUrl}/{activeOU}/siteview/data/{table}?pagesize={pagesize}&cursor={cursor}&{filterColumn}={filterValue}"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL


def svPostBatchJob(access_token,subscription_key,rootUrl,activeOU,siteview,table,body):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    body = body
    url = F"{rootUrl}/{activeOU}/siteview/data/{table}/batchjob"
    batchJobID = r.post(url=url,headers=call_headers,json=body)
    return batchJobID



def svGetBatchJob(access_token,subscription_key,rootUrl,activeOU,siteview,batchJobID):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    url = F"{rootUrl}/{activeOU}/siteview/data/batchjob/{batchJobID}"

    batch = r.get(url=url,headers=call_headers)
    return batch

def svReturnBatchStatus(access_token,subscription_key,url,siteview):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "siteview":siteview
                }
    url = F"{url}"
    batch_status = r.get(url=url,headers=call_headers)
    return batch_status



import requests as r
import json

def getwvTableAll(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getwvTableChanges(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor,date):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/changedrecords/{table}?pagesize={pagesize}&cursor={cursor}&startdateutc={date}"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL


def getwvWellHeaderAPI(apiNum,access_token,subscription_key,rootUrl,activeOU,wellview):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/wvwellheader?$wellida=${apiNum}"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getwvTableSingleFilter(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor,filterColumn,filterValue):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}?pagesize={pagesize}&cursor={cursor}&{filterColumn}={filterValue}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getwvTableThreeFilter(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor,filterColumn,filterValue,sfilterColumn,sfilterValue,tfilterColumn,tfilterValue):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}?pagesize={pagesize}&cursor={cursor}&{filterColumn}={filterValue}&{sfilterColumn}={sfilterValue}&{tfilterColumn}={tfilterValue}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL


def putwvNotesByWellByJob(access_token,subscription_key,rootUrl,activeOU,wellview,idwell,idrec,notes):
    url = F"{rootUrl}/{activeOU}/wellview/data/wvJobReportCostGen/entityId/{idwell}/recordId/{idrec}/note"
    put_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    payload = json.dumps(notes)         
    updateNotes = r.put(url=url,headers=put_headers,data=payload)
    return updateNotes



def wvPostBatchJob(access_token,subscription_key,rootUrl,activeOU,wellview,table,body):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    body = body
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/batchjob"
    batchJobID = r.post(url=url,headers=call_headers,json=body)
    return batchJobID



def wvGetBatchJob(access_token,subscription_key,rootUrl,activeOU,wellview,batchJobID):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/batchjob/{batchJobID}"

    batch = r.get(url=url,headers=call_headers)
    return batch

def wvReturnBatchStatus(access_token,subscription_key,url,wellview):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{url}"
    batch_status = r.get(url=url,headers=call_headers)
    return batch_status

def getwvTableByEntityID(access_token,subscription_key,rootUrl,activeOU,wellview,table,cursor,pagesize,entityId):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{entityId}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getwvTableByEntityID_singleFilter(access_token,subscription_key,rootUrl,activeOU,wellview,table,cursor,pagesize,entityId,filterColumn,filterValue):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{entityId}?${filterColumn}=${filterValue}&?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL

def getwvTableForParent(access_token,subscription_key,rootUrl,activeOU,wellview,table,pagesize,cursor,parentId):
    call_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/parentId/{parentId}?pagesize={pagesize}&cursor={cursor}&includecalcs=true&unitset=us"
    IDWELL = r.get(url=url,headers=call_headers)
    return IDWELL


def putwvColumnByIDREC(access_token,subscription_key,rootUrl,activeOU,wellview,table,idwell,idrec,column,writeVal):
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}/entityId/{idwell}/recordId/{idrec}/{column}?$unitset=us"
    put_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    payload = json.dumps(writeVal)         
    updateColumn = r.put(url=url,headers=put_headers,data=payload)
    return updateColumn


def postwvRowByIDWELL(access_token,subscription_key,rootUrl,activeOU,wellview,table,writeVal):
    url = F"{rootUrl}/{activeOU}/wellview/data/{table}"
    post_headers = {
                "Content-Type":'application/json',
                "Authorization":"Bearer %s" %(access_token),
                "Ocp-Apim-Subscription-Key":subscription_key,
                "wellview":wellview
                }
    payload = json.dumps(writeVal)         
    insertRow = r.post(url=url,headers=post_headers,data=payload)
    return insertRow
